@@ -32,7 +32,7 @@ except ImportError:
 # update it when the contents of directories change.
 if os.path.exists('MANIFEST'): os.remove('MANIFEST')
 
-from pkg_resources import parse_version
+from packaging.version import VERSION_PATTERN
 from setuptools import Command
 from setuptools.command.build_py import build_py
 from setuptools.config import StaticModule
@@ -56,13 +56,15 @@ else:
         return ' '.join(map(pipes.quote, cmd_list))
 
 
-__version__ = '0.9.0'
+__version__ = '0.10.0'
 
 # ---------------------------------------------------------------------------
 # Top Level Variables
 # ---------------------------------------------------------------------------
 
 SEPARATORS = os.sep if os.altsep is None else os.sep + os.altsep
+VERSION_REGEX = re.compile(r"^\s*" + VERSION_PATTERN + r"\s*$", re.VERBOSE | re.IGNORECASE)
+
 
 if "--skip-npm" in sys.argv:
     print("Skipping npm install as requested.")
@@ -76,7 +78,7 @@ else:
 # Core Functions
 # ---------------------------------------------------------------------------
 
-def wrap_installers(pre_develop=None, pre_dist=None, post_develop=None, post_dist=None, ensured_targets=None):
+def wrap_installers(pre_develop=None, pre_dist=None, post_develop=None, post_dist=None, ensured_targets=None, skip_if_exists=None):
     """Make a setuptools cmdclass that calls a prebuild function before installing.
 
     Parameters
@@ -91,6 +93,8 @@ def wrap_installers(pre_develop=None, pre_dist=None, post_develop=None, post_dis
         The function to call after the sdist and wheel commands.
     ensured_targets: list
         A list of local file paths that should exist when the dist commands are run
+    skip_if_exists: list
+        A list of local files whose presence causes the prebuild to skip
 
     Notes
     -----
@@ -118,15 +122,20 @@ def wrap_installers(pre_develop=None, pre_dist=None, post_develop=None, post_dis
 
     cmdclass['ensure_targets'] = ensure_targets(ensured_targets or [])
 
+    skip_if_exists = skip_if_exists or []
+    should_skip = all(Path(path).exists() for path in skip_if_exists)
+
     def _make_wrapper(klass, pre_build, post_build):
         class _Wrapped(klass):
             def run(self):
-                if pre_build:
+                if pre_build and not should_skip:
                     self.run_command(pre_build.__name__)
-                self.run_command('ensure_targets')
+                if klass != develop:
+                    self.run_command('ensure_targets')
                 klass.run(self)
-                if post_build:
+                if post_build and not should_skip:
                     self.run_command(post_build.__name__)
+
         cmdclass[klass.__name__] = _Wrapped
 
     if pre_develop or post_develop:
@@ -167,6 +176,7 @@ def npm_builder(path=None, build_dir=None, source_dir=None, build_cmd='build',
         if skip_npm:
             log.info('Skipping npm-installation')
             return
+
         node_package = path or os.path.abspath(os.getcwd())
         node_modules = pjoin(node_package, 'node_modules')
         is_yarn = os.path.exists(pjoin(node_package, 'yarn.lock'))
@@ -196,6 +206,7 @@ def npm_builder(path=None, build_dir=None, source_dir=None, build_cmd='build',
             run(npm_cmd + ['install'], cwd=node_package)
             if build_cmd:
                 run(npm_cmd + ['run', build_cmd], cwd=node_package)
+
     return builder
 
 # ---------------------------------------------------------------------------
@@ -243,10 +254,13 @@ def get_version(fpath, name='__version__'):
 
 def get_version_info(version_str):
     """Get a version info tuple given a version string"""
-    parsed = parse_version(version_str)
-    version_info = [parsed.major, parsed.minor, parsed.micro]
-    if parsed.base_version != parsed.public:
-        version_info.append(parsed.public[len(parsed.base_version):])
+    match = VERSION_REGEX.match(version_str)
+    if not match:
+        raise ValueError(f'Invalid version "{version_str}"')
+    release = match['release']
+    version_info = [int(p) for p in release.split('.')]
+    if release != version_str:
+        version_info.append(version_str[len(release):])
     return tuple(version_info)
 
 
